@@ -208,12 +208,10 @@ def add_analytics(
         user_id: str,
         accounts: Optional[list[str]] = None,
         with_holdings: bool = Query(
-            False,
-            description="Use real holdings data from investment provider for accurate P/L"
+            False, description="Use real holdings data from investment provider for accurate P/L"
         ),
         access_token: Optional[str] = Query(
-            None,
-            description="Investment provider access token (required if with_holdings=true)"
+            None, description="Investment provider access token (required if with_holdings=true)"
         ),
     ) -> PortfolioMetrics:
         """
@@ -249,31 +247,31 @@ def add_analytics(
         if with_holdings:
             # Check if investment provider is available on app state
             investment_provider = getattr(app.state, "investment_provider", None)
-            
+
             if investment_provider and access_token:
                 try:
                     # Fetch real holdings from investment provider
                     from fin_infra.analytics.portfolio import portfolio_metrics_with_holdings
-                    
+
                     holdings = await investment_provider.get_holdings(
                         access_token=access_token,
                         account_ids=accounts,
                     )
-                    
+
                     # Calculate metrics from real holdings
                     return portfolio_metrics_with_holdings(holdings)
-                    
+
                 except Exception as e:
                     # Fall back to balance-only calculation on error
                     # Log error but don't fail the request
                     import logging
+
                     logging.warning(f"Failed to fetch holdings, falling back to balance-only: {e}")
             elif with_holdings and not access_token:
                 raise HTTPException(
-                    status_code=400,
-                    detail="access_token required when with_holdings=true"
+                    status_code=400, detail="access_token required when with_holdings=true"
                 )
-        
+
         # Default: Use balance-only calculation (existing behavior)
         return await provider.portfolio_metrics(
             user_id,
