@@ -12,7 +12,7 @@ Generic Applicability:
 
 Features:
 - Statistical analysis: Top merchants, category breakdowns, trends, anomalies
-- LLM-powered insights: Personalized recommendations using ai-infra CoreLLM
+- LLM-powered insights: Personalized recommendations using ai-infra LLM
 - Graceful degradation: Falls back to rule-based insights if LLM unavailable
 - Cost-effective: Structured output for predictable token usage (<$0.01/insight)
 
@@ -44,6 +44,7 @@ Examples:
 
 from collections import defaultdict
 from datetime import timedelta
+from decimal import Decimal
 from typing import Optional
 
 from fin_infra.analytics.models import (
@@ -132,7 +133,7 @@ async def analyze_spending(
         ]
 
     # Calculate top merchants
-    merchant_totals: dict[str, float] = defaultdict(float)
+    merchant_totals: dict[str, Decimal] = defaultdict(Decimal)
     for t in expense_transactions:
         merchant = _extract_merchant_name(t.description or "Unknown")
         merchant_totals[merchant] += abs(t.amount)
@@ -142,7 +143,7 @@ async def analyze_spending(
     ]  # Top 10 merchants
 
     # Calculate category breakdown
-    category_totals: dict[str, float] = defaultdict(float)
+    category_totals: dict[str, Decimal] = defaultdict(Decimal)
     for t in expense_transactions:
         category = _get_transaction_category(t)
         category_totals[category] += abs(t.amount)
@@ -161,12 +162,13 @@ async def analyze_spending(
     )
 
     return SpendingInsight(
-        top_merchants=top_merchants,
-        category_breakdown=dict(category_totals),
+        # Convert Decimal to float for model compatibility (intentional for Pydantic field types)
+        top_merchants=[(m, float(v)) for m, v in top_merchants],
+        category_breakdown={k: float(v) for k, v in category_totals.items()},
         spending_trends=spending_trends,
         anomalies=anomalies,
         period_days=days,
-        total_spending=total_spending,
+        total_spending=float(total_spending) if total_spending else 0.0,
     )
 
 
@@ -261,7 +263,7 @@ def _get_transaction_category(transaction: Transaction) -> str:
 
 async def _calculate_spending_trends(
     user_id: str,
-    current_category_totals: dict[str, float],
+    current_category_totals: dict[str, Decimal],
     current_period_days: int,
     banking_provider=None,
     categorization_provider=None,
@@ -288,12 +290,12 @@ async def _calculate_spending_trends(
     for category, current_amount in current_category_totals.items():
         # Mock: assume previous period was 10% lower on average
         # In reality, would fetch historical data
-        previous_amount = current_amount * 0.9
+        previous_amount = current_amount * Decimal("0.9")
 
-        change_percent = (
-            ((current_amount - previous_amount) / previous_amount) * 100
+        change_percent: float = (
+            float((current_amount - previous_amount) / previous_amount) * 100
             if previous_amount > 0
-            else 0
+            else 0.0
         )
 
         # Threshold for "stable" is within 5%
@@ -311,7 +313,7 @@ async def _calculate_spending_trends(
 
 async def _detect_spending_anomalies(
     user_id: str,
-    current_category_totals: dict[str, float],
+    current_category_totals: dict[str, Decimal],
     current_period_days: int,
     banking_provider=None,
     categorization_provider=None,
@@ -339,10 +341,12 @@ async def _detect_spending_anomalies(
     for category, current_amount in current_category_totals.items():
         # Mock: assume historical average is current amount * 0.8
         # In reality, would calculate from historical data
-        average_amount = current_amount * 0.8
+        average_amount = current_amount * Decimal("0.8")
 
-        deviation_percent = (
-            ((current_amount - average_amount) / average_amount) * 100 if average_amount > 0 else 0
+        deviation_percent: float = (
+            float((current_amount - average_amount) / average_amount) * 100
+            if average_amount > 0
+            else 0.0
         )
 
         # Detect anomalies based on deviation
@@ -358,9 +362,10 @@ async def _detect_spending_anomalies(
         anomalies.append(
             SpendingAnomaly(
                 category=category,
-                current_amount=current_amount,
-                average_amount=average_amount,
-                deviation_percent=deviation_percent,
+                # Convert Decimal to float for model compatibility (intentional for Pydantic field types)
+                current_amount=float(current_amount),
+                average_amount=float(average_amount),
+                deviation_percent=float(deviation_percent),
                 severity=severity,
             )
         )
@@ -409,7 +414,7 @@ def _generate_mock_transactions(days: int) -> list[Transaction]:
                 Transaction(
                     id=f"mock_{i}",
                     account_id="mock_account",
-                    amount=float(amount),
+                    amount=Decimal(str(amount)),
                     date=base_date - timedelta(days=days_ago),
                     description=description,
                 )
@@ -426,12 +431,12 @@ async def generate_spending_insights(
 ) -> "PersonalizedSpendingAdvice":
     """Generate personalized spending insights using LLM.
 
-    Uses ai-infra CoreLLM for structured output generation with financial context.
+    Uses ai-infra LLM for structured output generation with financial context.
 
     Args:
         spending_insight: Analyzed spending data from analyze_spending()
         user_context: Optional context (income, goals, budget, preferences)
-        llm_provider: Optional CoreLLM instance (defaults to Google Gemini)
+        llm_provider: Optional LLM instance (defaults to Google Gemini)
 
     Returns:
         PersonalizedSpendingAdvice with LLM-generated recommendations
@@ -467,14 +472,14 @@ async def generate_spending_insights(
 
     # Try to import ai-infra LLM (optional dependency)
     try:
-        from ai_infra.llm import CoreLLM
+        from ai_infra.llm import LLM
     except ImportError:
         # Graceful degradation: return rule-based insights
         return _generate_rule_based_insights(spending_insight, user_context)
 
     # Initialize LLM if not provided
     if llm_provider is None:
-        llm_provider = CoreLLM()
+        llm_provider = LLM()
 
     # Build financial context prompt
     prompt = _build_spending_insights_prompt(spending_insight, user_context)
