@@ -45,7 +45,7 @@ from __future__ import annotations
 
 import os
 from datetime import date
-from typing import TYPE_CHECKING, Optional
+from typing import TYPE_CHECKING, Optional, cast
 
 from pydantic import BaseModel, Field
 
@@ -174,7 +174,6 @@ def easy_banking(provider: str = "teller", **config) -> BankingProvider:
     See Also:
         - add_banking(): For FastAPI integration with routes
         - docs/banking.md: Comprehensive banking integration guide
-        - docs/adr/0003-banking-integration.md: Architecture decisions
     """
     # Auto-detect provider config from environment if not explicitly provided
     # Only auto-detect if no config params were passed
@@ -199,7 +198,7 @@ def easy_banking(provider: str = "teller", **config) -> BankingProvider:
             }
 
     # Use provider registry to dynamically load and configure provider
-    return resolve("banking", provider, **config)
+    return cast(BankingProvider, resolve("banking", provider, **config))
 
 
 def add_banking(
@@ -397,10 +396,13 @@ def add_banking(
             }
         """
         # Get all transactions from provider
+        # Convert date to ISO string format as expected by BankingProvider.transactions()
+        start_date_str: str | None = start_date.isoformat() if start_date else None
+        end_date_str: str | None = end_date.isoformat() if end_date else None
         transactions = banking.transactions(
             access_token=access_token,
-            start_date=start_date,
-            end_date=end_date,
+            start_date=start_date_str,
+            end_date=end_date_str,
         )
 
         # Apply filters
@@ -589,7 +591,7 @@ def add_banking(
 
 
 # Import utilities at end to avoid circular imports
-from .utils import (
+from .utils import (  # noqa: E402
     validate_plaid_token,
     validate_teller_token,
     validate_mx_token,
