@@ -10,19 +10,19 @@ Provides conversational interface for financial Q&A:
 - Personalized advice (uses current net worth, goals, historical data)
 - Natural dialogue (flexible responses, not forced JSON structure)
 
-**Design Choice**: Uses `CoreLLM.achat()` for natural conversation (NOT `with_structured_output()`).
+**Design Choice**: Uses `LLM.achat()` for natural conversation (NOT `with_structured_output()`).
 Conversation should be flexible and natural, not rigidly structured. Other modules (insights,
 categorization, goals) correctly use structured output because they need predictable schemas.
 
-Uses ai-infra CoreLLM for natural conversation.
+Uses ai-infra LLM for natural conversation.
 Caches conversation context for 24h (target: $0.018/user/month cost).
 
 Example:
-    from ai_infra.llm import CoreLLM
+    from ai_infra.llm import LLM
     from svc_infra.cache import get_cache
     from fin_infra.conversation import FinancialPlanningConversation
 
-    llm = CoreLLM()
+    llm = LLM()
     cache = get_cache()
     conversation = FinancialPlanningConversation(
         llm=llm,
@@ -196,10 +196,10 @@ class FinancialPlanningConversation:
     Cost: ~$0.0054/conversation (10 turns with context caching)
 
     Example:
-        from ai_infra.llm import CoreLLM
+        from ai_infra.llm import LLM
         from svc_infra.cache import get_cache
 
-        llm = CoreLLM()
+        llm = LLM()
         cache = get_cache()
         conversation = FinancialPlanningConversation(
             llm=llm,
@@ -232,7 +232,7 @@ class FinancialPlanningConversation:
         Initialize conversation manager.
 
         Args:
-            llm: ai-infra CoreLLM instance
+            llm: ai-infra LLM instance
             cache: svc-infra cache instance (for context storage)
             provider: LLM provider ("google", "openai", "anthropic")
             model_name: Model name (default: gemini-2.0-flash-exp)
@@ -338,8 +338,65 @@ class FinancialPlanningConversation:
         # Save updated context (24h TTL)
         await self._save_context(context)
 
+        # Track latest session id for convenience endpoints (history/clear).
+        # Best-effort: failures here must not break the chat response.
+        try:
+            await self.cache.set(
+                self._latest_session_key(user_id),
+                context.session_id,
+                ttl=86400,
+            )
+        except Exception:
+            pass
+
         return response
 
+    # ---------------------------------------------------------------------
+    # Backward-compatible context helpers
+    # ---------------------------------------------------------------------
+
+    def _latest_session_key(self, user_id: str) -> str:
+        return f"fin_infra:conversation_latest_session:{user_id}"
+
+    async def _get_latest_session_id(self, user_id: str) -> str | None:
+        try:
+            value = await self.cache.get(self._latest_session_key(user_id))
+        except Exception:
+            return None
+
+        if value is None:
+            return None
+        if isinstance(value, bytes):
+            try:
+                return value.decode("utf-8")
+            except Exception:
+                return None
+        if isinstance(value, str):
+            return value
+        return str(value)
+
+    async def _get_context(
+        self, user_id: str, session_id: str | None = None
+    ) -> ConversationContext | None:
+        if session_id is None:
+            session_id = await self._get_latest_session_id(user_id)
+        if session_id is None:
+            return None
+
+        return await self._load_context(user_id=user_id, session_id=session_id)
+
+    async def _clear_context(self, user_id: str, session_id: str | None = None) -> None:
+        if session_id is None:
+            session_id = await self._get_latest_session_id(user_id)
+
+        if session_id is not None:
+            await self.clear_session(user_id=user_id, session_id=session_id)
+
+        try:
+            await self.cache.delete(self._latest_session_key(user_id))
+        except Exception:
+            pass
+
     async def _load_context(
         self,
         user_id: str,
