@@ -21,7 +21,8 @@ from __future__ import annotations
 
 import logging
 from datetime import datetime
-from typing import Any, Callable, TYPE_CHECKING
+from typing import Any, TYPE_CHECKING, cast
+from collections.abc import Callable
 
 if TYPE_CHECKING:
     from fastapi import FastAPI, Request, Response
@@ -118,7 +119,7 @@ def add_compliance_tracking(
 
         # Track only GET requests (data access)
         if method != "GET":
-            return await call_next(request)
+            return cast("Response", await call_next(request))
 
         # Determine if path is a compliance-tracked endpoint
         event = None
@@ -148,7 +149,7 @@ def add_compliance_tracking(
             if on_event:
                 on_event(event, context)
 
-        return response
+        return cast("Response", response)
 
     logger.info(
         "Compliance tracking enabled",
