@@ -25,7 +25,7 @@ from __future__ import annotations
 
 import re
 from datetime import datetime
-from typing import TYPE_CHECKING, Dict, Optional
+from typing import TYPE_CHECKING, Optional
 
 if TYPE_CHECKING:
     from svc_infra.storage.base import StorageBackend
@@ -33,7 +33,7 @@ if TYPE_CHECKING:
     from .models import OCRResult
 
 # In-memory OCR cache (production: use svc-infra cache)
-_ocr_cache: Dict[str, "OCRResult"] = {}
+_ocr_cache: dict[str, "OCRResult"] = {}
 
 
 async def extract_text(
@@ -46,7 +46,7 @@ async def extract_text(
     Extract text from a document using OCR (uses svc-infra storage).
 
     Args:
-        storage: Storage backend instance  
+        storage: Storage backend instance
         document_id: Document identifier
         provider: OCR provider ("tesseract" or "textract")
         force_refresh: Force re-extraction even if cached result exists
