@@ -7,14 +7,14 @@ Provides 4 goal types with validation and progress tracking:
 3. Debt-Free Goal: Debt payoff schedule with APR calculations
 4. Wealth Milestone: Project growth to target net worth
 
-Uses ai-infra CoreLLM for validation + local math for calculations.
+Uses ai-infra LLM for validation + local math for calculations.
 Weekly progress check-ins via svc-infra.jobs scheduler ($0.0036/user/month).
 
 Example:
-    from ai_infra.llm import CoreLLM
+    from ai_infra.llm import LLM
     from fin_infra.goals.management import FinancialGoalTracker
 
-    llm = CoreLLM()
+    llm = LLM()
     tracker = FinancialGoalTracker(
         llm=llm,
         provider="google",
@@ -41,7 +41,7 @@ Example:
 """
 
 from datetime import datetime
-from typing import Any
+from typing import Any, cast
 
 from pydantic import BaseModel, Field
 
@@ -475,9 +475,9 @@ class FinancialGoalTracker:
     Cost: ~$0.0009/validation, ~$0.0009/week for progress ($0.0036/user/month)
 
     Example:
-        from ai_infra.llm import CoreLLM
+        from ai_infra.llm import LLM
 
-        llm = CoreLLM()
+        llm = LLM()
         tracker = FinancialGoalTracker(llm=llm, provider="google")
 
         # Validate goal
@@ -503,7 +503,7 @@ class FinancialGoalTracker:
         Initialize goal tracker.
 
         Args:
-            llm: ai-infra CoreLLM instance
+            llm: ai-infra LLM instance
             provider: LLM provider ("google", "openai", "anthropic")
             model_name: Model name (default: gemini-2.0-flash-exp)
         """
@@ -597,10 +597,10 @@ Goal type: {goal_type}
 Goal data: {goal}
 
 CALCULATED VALUES (use these exactly, don't recalculate):
-- Feasibility: {calc['feasibility']}
-- Required monthly: ${calc['required_monthly']:,.0f}
+- Feasibility: {calc["feasibility"]}
+- Required monthly: ${calc["required_monthly"]:,.0f}
 - Projected completion: {projected_date}
-- Current progress: {calc['current_progress']:.1%}
+- Current progress: {calc["current_progress"]:.1%}
 
 Provide context and advice around these calculations. Suggest 2-3 alternative paths and 3-5 specific recommendations."""
 
@@ -839,7 +839,7 @@ def get_goal(goal_id: str) -> dict[str, Any]:
     if goal_id not in _GOALS_STORE:
         raise KeyError(f"Goal not found: {goal_id}")
 
-    return _GOALS_STORE[goal_id]
+    return cast(dict[str, Any], _GOALS_STORE[goal_id])
 
 
 def update_goal(
@@ -885,7 +885,7 @@ def update_goal(
 
     Goal(**goal)  # Will raise ValidationError if invalid
 
-    return goal
+    return cast(dict[str, Any], goal)
 
 
 def delete_goal(goal_id: str) -> None:
