@@ -17,17 +17,17 @@ Models are provider-agnostic and normalize data from Plaid, SnapTrade, etc.
 
 from __future__ import annotations
 
-from datetime import date, datetime
+from datetime import date
 from decimal import Decimal
 from enum import Enum
-from typing import Dict, List, Optional
+from typing import TYPE_CHECKING, Optional
 
 from pydantic import BaseModel, ConfigDict, Field, computed_field
 
 
 class SecurityType(str, Enum):
     """Security type classification.
-    
+
     Categories:
     - equity: Common stock (AAPL, GOOGL, etc.)
     - etf: Exchange-traded fund (SPY, QQQ, etc.)
@@ -49,7 +49,7 @@ class SecurityType(str, Enum):
 
 class TransactionType(str, Enum):
     """Investment transaction type.
-    
+
     Categories:
     - buy: Purchase of security
     - sell: Sale of security
@@ -71,7 +71,7 @@ class TransactionType(str, Enum):
     fee = "fee"
     tax = "tax"
     transfer = "transfer"
-    split = "split"
+    split = "split"  # type: ignore[assignment]  # str.split() name conflict
     merger = "merger"
     cancel = "cancel"
     other = "other"
@@ -79,10 +79,10 @@ class TransactionType(str, Enum):
 
 class Security(BaseModel):
     """Security details (stock, bond, ETF, etc.).
-    
+
     Represents a tradable security with identifying information and current market data.
     Normalized across providers (Plaid, SnapTrade).
-    
+
     Example:
         >>> security = Security(
         ...     security_id="plaid_sec_123",
@@ -129,7 +129,9 @@ class Security(BaseModel):
     # Basic info
     name: str = Field(..., description="Security name")
     type: SecurityType = Field(..., description="Security type (equity, etf, bond, etc.)")
-    sector: Optional[str] = Field(None, description="Sector classification (Technology, Healthcare)")
+    sector: Optional[str] = Field(
+        None, description="Sector classification (Technology, Healthcare)"
+    )
 
     # Market data
     close_price: Optional[Decimal] = Field(None, ge=0, description="Latest closing price")
@@ -140,10 +142,10 @@ class Security(BaseModel):
 
 class Holding(BaseModel):
     """Investment holding with current value and cost basis.
-    
+
     Represents a position in a specific security within an investment account.
     Includes quantity, current value, cost basis, and calculated P&L.
-    
+
     Example:
         >>> holding = Holding(
         ...     account_id="acct_123",
@@ -193,38 +195,61 @@ class Holding(BaseModel):
     # Position data
     quantity: Decimal = Field(..., ge=0, description="Number of shares/units held")
     institution_price: Decimal = Field(..., ge=0, description="Current price per share")
-    institution_value: Decimal = Field(..., ge=0, description="Current market value (quantity × price)")
-    cost_basis: Optional[Decimal] = Field(None, ge=0, description="Total cost basis (original purchase price)")
+    institution_value: Decimal = Field(
+        ..., ge=0, description="Current market value (quantity × price)"
+    )
+    cost_basis: Optional[Decimal] = Field(
+        None, ge=0, description="Total cost basis (original purchase price)"
+    )
 
     # Additional data
     currency: str = Field("USD", description="Currency code")
     unofficial_currency_code: Optional[str] = Field(None, description="For crypto/alt currencies")
     as_of_date: Optional[date] = Field(None, description="Date of pricing data")
 
-    @computed_field  # type: ignore[misc]
-    @property
-    def unrealized_gain_loss(self) -> Optional[Decimal]:
-        """Calculate unrealized gain/loss (current value - cost basis)."""
-        if self.cost_basis is None:
-            return None
-        return self.institution_value - self.cost_basis
+    if TYPE_CHECKING:
 
-    @computed_field  # type: ignore[misc]
-    @property
-    def unrealized_gain_loss_percent(self) -> Optional[Decimal]:
-        """Calculate unrealized gain/loss percentage."""
-        if self.cost_basis is None or self.cost_basis == 0:
-            return None
-        gain_loss = self.institution_value - self.cost_basis
-        return round((gain_loss / self.cost_basis) * 100, 2)
+        @property
+        def unrealized_gain_loss(self) -> Optional[Decimal]:
+            """Calculate unrealized gain/loss (current value - cost basis)."""
+            if self.cost_basis is None:
+                return None
+            return self.institution_value - self.cost_basis
+
+        @property
+        def unrealized_gain_loss_percent(self) -> Optional[Decimal]:
+            """Calculate unrealized gain/loss percentage."""
+            if self.cost_basis is None or self.cost_basis == 0:
+                return None
+            gain_loss = self.institution_value - self.cost_basis
+            return round((gain_loss / self.cost_basis) * 100, 2)
+
+    else:
+
+        @computed_field
+        @property
+        def unrealized_gain_loss(self) -> Optional[Decimal]:
+            """Calculate unrealized gain/loss (current value - cost basis)."""
+            if self.cost_basis is None:
+                return None
+            return self.institution_value - self.cost_basis
+
+        @computed_field
+        @property
+        def unrealized_gain_loss_percent(self) -> Optional[Decimal]:
+            """Calculate unrealized gain/loss percentage."""
+            if self.cost_basis is None or self.cost_basis == 0:
+                return None
+            gain_loss = self.institution_value - self.cost_basis
+            return round((gain_loss / self.cost_basis) * 100, 2)
 
 
 class InvestmentTransaction(BaseModel):
     """Investment transaction (buy, sell, dividend, etc.).
-    
+
     Represents a single transaction in an investment account.
     Used to calculate realized gains and track transaction history.
-    
+
     Example:
         >>> transaction = InvestmentTransaction(
         ...     transaction_id="tx_123",
@@ -276,7 +301,9 @@ class InvestmentTransaction(BaseModel):
     # Transaction details
     transaction_date: date = Field(..., alias="date", description="Transaction date")
     name: str = Field(..., description="Transaction description")
-    transaction_type: TransactionType = Field(..., alias="type", description="Transaction type (buy, sell, dividend)")
+    transaction_type: TransactionType = Field(
+        ..., alias="type", description="Transaction type (buy, sell, dividend)"
+    )
     subtype: Optional[str] = Field(None, description="Provider-specific subtype")
 
     # Amounts
@@ -292,10 +319,10 @@ class InvestmentTransaction(BaseModel):
 
 class InvestmentAccount(BaseModel):
     """Investment account with aggregated holdings and metrics.
-    
+
     Represents a complete investment account with all holdings, balances, and P&L.
     Includes calculated fields for total value, cost basis, and unrealized gains.
-    
+
     Example:
         >>> account = InvestmentAccount(
         ...     account_id="acct_123",
@@ -321,7 +348,11 @@ class InvestmentAccount(BaseModel):
                 "holdings": [
                     {
                         "account_id": "acct_abc123",
-                        "security": {"ticker_symbol": "AAPL", "name": "Apple Inc.", "type": "equity"},
+                        "security": {
+                            "ticker_symbol": "AAPL",
+                            "name": "Apple Inc.",
+                            "type": "equity",
+                        },
                         "quantity": 10.5,
                         "institution_price": 150.25,
                         "institution_value": 1577.63,
@@ -343,49 +374,84 @@ class InvestmentAccount(BaseModel):
     subtype: Optional[str] = Field(None, description="Account subtype (401k, ira, brokerage)")
 
     # Balances
-    balances: Dict[str, Optional[Decimal]] = Field(
+    balances: dict[str, Optional[Decimal]] = Field(
         ..., description="Current, available, and limit balances"
     )
 
     # Holdings
-    holdings: List[Holding] = Field(default_factory=list, description="List of holdings in account")
+    holdings: list[Holding] = Field(default_factory=list, description="List of holdings in account")
 
-    @computed_field  # type: ignore[misc]
-    @property
-    def total_value(self) -> Decimal:
-        """Calculate total account value (sum of holdings + cash)."""
-        holdings_value = sum(h.institution_value for h in self.holdings)
-        cash_balance = self.balances.get("current") or Decimal(0)
-        return holdings_value + cash_balance
+    if TYPE_CHECKING:
 
-    @computed_field  # type: ignore[misc]
-    @property
-    def total_cost_basis(self) -> Decimal:
-        """Calculate total cost basis (sum of cost_basis across holdings)."""
-        return sum(h.cost_basis for h in self.holdings if h.cost_basis is not None)
+        @property
+        def total_value(self) -> Decimal:
+            """Calculate total account value (sum of holdings + cash)."""
+            holdings_value = sum((h.institution_value for h in self.holdings), start=Decimal(0))
+            cash_balance = self.balances.get("current") or Decimal(0)
+            return holdings_value + cash_balance
 
-    @computed_field  # type: ignore[misc]
-    @property
-    def total_unrealized_gain_loss(self) -> Decimal:
-        """Calculate total unrealized P&L (value - cost_basis)."""
-        holdings_value = sum(h.institution_value for h in self.holdings)
-        return holdings_value - self.total_cost_basis
+        @property
+        def total_cost_basis(self) -> Decimal:
+            """Calculate total cost basis (sum of cost_basis across holdings)."""
+            return sum(
+                (h.cost_basis for h in self.holdings if h.cost_basis is not None),
+                start=Decimal(0),
+            )
 
-    @computed_field  # type: ignore[misc]
-    @property
-    def total_unrealized_gain_loss_percent(self) -> Optional[Decimal]:
-        """Calculate total unrealized P&L percentage."""
-        if self.total_cost_basis == 0:
-            return None
-        return round((self.total_unrealized_gain_loss / self.total_cost_basis) * 100, 2)
+        @property
+        def total_unrealized_gain_loss(self) -> Decimal:
+            """Calculate total unrealized P&L (value - cost_basis)."""
+            holdings_value = sum((h.institution_value for h in self.holdings), start=Decimal(0))
+            return holdings_value - self.total_cost_basis
+
+        @property
+        def total_unrealized_gain_loss_percent(self) -> Optional[Decimal]:
+            """Calculate total unrealized P&L percentage."""
+            if self.total_cost_basis == 0:
+                return None
+            return round((self.total_unrealized_gain_loss / self.total_cost_basis) * 100, 2)
+
+    else:
+
+        @computed_field
+        @property
+        def total_value(self) -> Decimal:
+            """Calculate total account value (sum of holdings + cash)."""
+            holdings_value = sum((h.institution_value for h in self.holdings), start=Decimal(0))
+            cash_balance = self.balances.get("current") or Decimal(0)
+            return holdings_value + cash_balance
+
+        @computed_field
+        @property
+        def total_cost_basis(self) -> Decimal:
+            """Calculate total cost basis (sum of cost_basis across holdings)."""
+            return sum(
+                (h.cost_basis for h in self.holdings if h.cost_basis is not None),
+                start=Decimal(0),
+            )
+
+        @computed_field
+        @property
+        def total_unrealized_gain_loss(self) -> Decimal:
+            """Calculate total unrealized P&L (value - cost_basis)."""
+            holdings_value = sum((h.institution_value for h in self.holdings), start=Decimal(0))
+            return holdings_value - self.total_cost_basis
+
+        @computed_field
+        @property
+        def total_unrealized_gain_loss_percent(self) -> Optional[Decimal]:
+            """Calculate total unrealized P&L percentage."""
+            if self.total_cost_basis == 0:
+                return None
+            return round((self.total_unrealized_gain_loss / self.total_cost_basis) * 100, 2)
 
 
 class AssetAllocation(BaseModel):
     """Asset allocation breakdown by security type and sector.
-    
+
     Provides percentage breakdown of portfolio by security type and sector.
     Used for diversification analysis and portfolio visualization.
-    
+
     Example:
         >>> allocation = AssetAllocation(
         ...     by_security_type={
@@ -421,11 +487,11 @@ class AssetAllocation(BaseModel):
         },
     )
 
-    by_security_type: Dict[SecurityType, float] = Field(
+    by_security_type: dict[SecurityType, float] = Field(
         default_factory=dict,
         description="Percentage breakdown by security type (equity, bond, etc.)",
     )
-    by_sector: Dict[str, float] = Field(
+    by_sector: dict[str, float] = Field(
         default_factory=dict,
         description="Percentage breakdown by sector (Technology, Healthcare, etc.)",
     )
