@@ -10,33 +10,55 @@ from __future__ import annotations
 
 from datetime import date
 from decimal import Decimal
-from typing import Any, Dict, List, Optional
+from typing import Any, Optional, cast
 
-from plaid.api import plaid_api
-from plaid.model.investments_holdings_get_request import InvestmentsHoldingsGetRequest
-from plaid.model.investments_transactions_get_request import (
-    InvestmentsTransactionsGetRequest,
-)
-from plaid.model.investments_holdings_get_response import InvestmentsHoldingsGetResponse
-from plaid.model.investments_transactions_get_response import (
-    InvestmentsTransactionsGetResponse,
-)
-from plaid.exceptions import ApiException
-import plaid
-from plaid.api_client import ApiClient
-from plaid.configuration import Configuration
+try:
+    from plaid.api import plaid_api
+    from plaid.model.investments_holdings_get_request import InvestmentsHoldingsGetRequest
+    from plaid.model.investments_transactions_get_request import (
+        InvestmentsTransactionsGetRequest,
+    )
+    from plaid.model.investments_holdings_get_response import InvestmentsHoldingsGetResponse
+    from plaid.model.investments_transactions_get_response import (
+        InvestmentsTransactionsGetResponse,
+    )
+    from plaid.exceptions import ApiException
+    import plaid
+    from plaid.api_client import ApiClient
+    from plaid.configuration import Configuration
+
+    HAS_PLAID = True
+except ImportError:  # pragma: no cover
+    HAS_PLAID = False
+    plaid_api = None
+    plaid = None
+    ApiClient = None
+    Configuration = None
+    ApiException = Exception
+    InvestmentsHoldingsGetRequest = Any
+    InvestmentsTransactionsGetRequest = Any
+    InvestmentsHoldingsGetResponse = Any
+    InvestmentsTransactionsGetResponse = Any
 
 from ..models import (
     Holding,
     InvestmentAccount,
     InvestmentTransaction,
     Security,
-    SecurityType,
     TransactionType,
 )
 from .base import InvestmentProvider
 
 
+def _require_plaid() -> None:
+    """Raise ImportError if plaid-python is not installed."""
+    if not HAS_PLAID:
+        raise ImportError(
+            "Plaid support requires the 'plaid-python' package. "
+            "Install with: pip install fin-infra[plaid] or pip install fin-infra[banking]"
+        )
+
+
 class PlaidInvestmentProvider(InvestmentProvider):
     """Plaid Investment API provider.
 
@@ -77,7 +99,10 @@ class PlaidInvestmentProvider(InvestmentProvider):
 
         Raises:
             ValueError: If client_id or secret is missing
+            ImportError: If plaid-python is not installed
         """
+        _require_plaid()
+
         if not client_id or not secret:
             raise ValueError("client_id and secret are required for Plaid provider")
 
@@ -103,11 +128,11 @@ class PlaidInvestmentProvider(InvestmentProvider):
             "development": plaid.Environment.Sandbox,  # Map development to sandbox
             "production": plaid.Environment.Production,
         }
-        return hosts.get(environment.lower(), plaid.Environment.Sandbox)
+        return cast(str, hosts.get(environment.lower(), plaid.Environment.Sandbox))
 
     async def get_holdings(
-        self, access_token: str, account_ids: Optional[List[str]] = None
-    ) -> List[Holding]:
+        self, access_token: str, account_ids: Optional[list[str]] = None
+    ) -> list[Holding]:
         """Fetch investment holdings from Plaid.
 
         Retrieves holdings with security details, quantity, cost basis, and current value.
@@ -136,9 +161,7 @@ class PlaidInvestmentProvider(InvestmentProvider):
             if account_ids:
                 request.options = {"account_ids": account_ids}
 
-            response: InvestmentsHoldingsGetResponse = (
-                self.client.investments_holdings_get(request)
-            )
+            response: InvestmentsHoldingsGetResponse = self.client.investments_holdings_get(request)
 
             # Build security lookup map
             securities_map = {
@@ -166,8 +189,8 @@ class PlaidInvestmentProvider(InvestmentProvider):
         access_token: str,
         start_date: date,
         end_date: date,
-        account_ids: Optional[List[str]] = None,
-    ) -> List[InvestmentTransaction]:
+        account_ids: Optional[list[str]] = None,
+    ) -> list[InvestmentTransaction]:
         """Fetch investment transactions from Plaid.
 
         Retrieves buy/sell/dividend transactions within the specified date range.
@@ -204,8 +227,8 @@ class PlaidInvestmentProvider(InvestmentProvider):
             if account_ids:
                 request.options = {"account_ids": account_ids}
 
-            response: InvestmentsTransactionsGetResponse = (
-                self.client.investments_transactions_get(request)
+            response: InvestmentsTransactionsGetResponse = self.client.investments_transactions_get(
+                request
             )
 
             # Build security lookup map
@@ -229,9 +252,7 @@ class PlaidInvestmentProvider(InvestmentProvider):
         except ApiException as e:
             raise self._transform_error(e)
 
-    async def get_securities(
-        self, access_token: str, security_ids: List[str]
-    ) -> List[Security]:
+    async def get_securities(self, access_token: str, security_ids: list[str]) -> list[Security]:
         """Fetch security details from Plaid holdings.
 
         Note: Plaid doesn't have a dedicated securities endpoint.
@@ -254,9 +275,7 @@ class PlaidInvestmentProvider(InvestmentProvider):
         """
         try:
             request = InvestmentsHoldingsGetRequest(access_token=access_token)
-            response: InvestmentsHoldingsGetResponse = (
-                self.client.investments_holdings_get(request)
-            )
+            response: InvestmentsHoldingsGetResponse = self.client.investments_holdings_get(request)
 
             # Filter securities by requested IDs
             securities = []
@@ -271,9 +290,7 @@ class PlaidInvestmentProvider(InvestmentProvider):
         except ApiException as e:
             raise self._transform_error(e)
 
-    async def get_investment_accounts(
-        self, access_token: str
-    ) -> List[InvestmentAccount]:
+    async def get_investment_accounts(self, access_token: str) -> list[InvestmentAccount]:
         """Fetch investment accounts with aggregated holdings.
 
         Returns accounts with total value, cost basis, and unrealized P&L.
@@ -295,9 +312,7 @@ class PlaidInvestmentProvider(InvestmentProvider):
         """
         try:
             request = InvestmentsHoldingsGetRequest(access_token=access_token)
-            response: InvestmentsHoldingsGetResponse = (
-                self.client.investments_holdings_get(request)
-            )
+            response: InvestmentsHoldingsGetResponse = self.client.investments_holdings_get(request)
 
             # Build security lookup map
             securities_map = {
@@ -306,7 +321,7 @@ class PlaidInvestmentProvider(InvestmentProvider):
             }
 
             # Group holdings by account
-            accounts_map: Dict[str, Dict[str, Any]] = {}
+            accounts_map: dict[str, dict[str, Any]] = {}
             for plaid_holding in response.holdings:
                 holding_dict = plaid_holding.to_dict()
                 account_id = holding_dict["account_id"]
@@ -318,11 +333,7 @@ class PlaidInvestmentProvider(InvestmentProvider):
                     if account_id not in accounts_map:
                         # Find account metadata
                         plaid_account = next(
-                            (
-                                acc
-                                for acc in response.accounts
-                                if acc.account_id == account_id
-                            ),
+                            (acc for acc in response.accounts if acc.account_id == account_id),
                             None,
                         )
                         accounts_map[account_id] = {
@@ -340,12 +351,16 @@ class PlaidInvestmentProvider(InvestmentProvider):
 
                 investment_account = InvestmentAccount(
                     account_id=account_id,
-                    name=account_dict.get("name", account_dict.get("official_name", "Unknown Account")),
+                    name=account_dict.get(
+                        "name", account_dict.get("official_name", "Unknown Account")
+                    ),
                     type=account_dict.get("type", "investment"),
                     subtype=account_dict.get("subtype"),
                     balances={
-                        "current": float(account_dict.get("balances", {}).get("current", 0)),
-                        "available": float(account_dict.get("balances", {}).get("available")),
+                        "current": Decimal(str(account_dict.get("balances", {}).get("current", 0))),
+                        "available": Decimal(
+                            str(account_dict.get("balances", {}).get("available") or 0)
+                        ),
                     },
                     holdings=holdings,
                 )
@@ -358,19 +373,19 @@ class PlaidInvestmentProvider(InvestmentProvider):
 
     # Helper methods for data transformation
 
-    def _transform_security(self, plaid_security: Dict[str, Any]) -> Security:
+    def _transform_security(self, plaid_security: dict[str, Any]) -> Security:
         """Transform Plaid security data to Security model."""
         # Handle close_price - Plaid may return None for securities without recent pricing
         close_price_raw = plaid_security.get("close_price")
         close_price = Decimal(str(close_price_raw)) if close_price_raw is not None else Decimal("0")
-        
+
         return Security(
             security_id=plaid_security["security_id"],
             cusip=plaid_security.get("cusip"),
             isin=plaid_security.get("isin"),
             sedol=plaid_security.get("sedol"),
             ticker_symbol=plaid_security.get("ticker_symbol"),
-            name=plaid_security.get("name"),
+            name=plaid_security.get("name") or "Unknown Security",
             type=self._normalize_security_type(plaid_security.get("type", "other")),
             sector=plaid_security.get("sector"),
             close_price=close_price,
@@ -379,9 +394,7 @@ class PlaidInvestmentProvider(InvestmentProvider):
             currency=plaid_security.get("iso_currency_code", "USD"),
         )
 
-    def _transform_holding(
-        self, plaid_holding: Dict[str, Any], security: Security
-    ) -> Holding:
+    def _transform_holding(self, plaid_holding: dict[str, Any], security: Security) -> Holding:
         """Transform Plaid holding data to Holding model."""
         return Holding(
             account_id=plaid_holding["account_id"],
@@ -389,13 +402,15 @@ class PlaidInvestmentProvider(InvestmentProvider):
             quantity=Decimal(str(plaid_holding.get("quantity", 0))),
             institution_price=Decimal(str(plaid_holding.get("institution_price", 0))),
             institution_value=Decimal(str(plaid_holding.get("institution_value", 0))),
-            cost_basis=Decimal(str(plaid_holding.get("cost_basis"))) if plaid_holding.get("cost_basis") else None,
+            cost_basis=Decimal(str(plaid_holding.get("cost_basis")))
+            if plaid_holding.get("cost_basis")
+            else None,
             currency=plaid_holding.get("iso_currency_code", "USD"),
             unofficial_currency_code=plaid_holding.get("unofficial_currency_code"),
         )
 
     def _transform_transaction(
-        self, plaid_transaction: Dict[str, Any], security: Security
+        self, plaid_transaction: dict[str, Any], security: Security
     ) -> InvestmentTransaction:
         """Transform Plaid investment transaction to InvestmentTransaction model."""
         # Map Plaid transaction type to our enum
