@@ -11,7 +11,7 @@ from __future__ import annotations
 
 from datetime import date
 from decimal import Decimal
-from typing import Any, Dict, List, Optional
+from typing import Any, Optional, cast
 
 import httpx
 
@@ -20,7 +20,6 @@ from ..models import (
     InvestmentAccount,
     InvestmentTransaction,
     Security,
-    SecurityType,
     TransactionType,
 )
 from .base import InvestmentProvider
@@ -78,9 +77,7 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
             ValueError: If client_id or consumer_key is missing
         """
         if not client_id or not consumer_key:
-            raise ValueError(
-                "client_id and consumer_key are required for SnapTrade provider"
-            )
+            raise ValueError("client_id and consumer_key are required for SnapTrade provider")
 
         self.client_id = client_id
         self.consumer_key = consumer_key
@@ -96,11 +93,30 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
             timeout=30.0,
         )
 
+    def _auth_headers(self, user_id: str, user_secret: str) -> dict[str, str]:
+        """Build authentication headers for SnapTrade API requests.
+
+        SECURITY: User secrets are passed in headers, NOT URL params.
+        URL params are logged in access logs, browser history, and proxy logs.
+        Headers are not logged by default in most web servers.
+
+        Args:
+            user_id: SnapTrade user ID
+            user_secret: SnapTrade user secret (sensitive!)
+
+        Returns:
+            Dict with authentication headers
+        """
+        return {
+            "userId": user_id,
+            "userSecret": user_secret,
+        }
+
     async def get_holdings(
         self,
         access_token: str,
-        account_ids: Optional[List[str]] = None,
-    ) -> List[Holding]:
+        account_ids: Optional[list[str]] = None,
+    ) -> list[Holding]:
         """Fetch investment holdings from SnapTrade.
 
         Note: SnapTrade uses user_id + user_secret, passed as access_token in format "user_id:user_secret"
@@ -123,12 +139,12 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
             ...     print(f"{holding.security.ticker_symbol}: P&L ${pnl}")
         """
         user_id, user_secret = self._parse_access_token(access_token)
+        auth_headers = self._auth_headers(user_id, user_secret)
 
         try:
             # Get all accounts
             accounts_url = f"{self.base_url}/accounts"
-            params = {"userId": user_id, "userSecret": user_secret}
-            response = await self.client.get(accounts_url, params=params)
+            response = await self.client.get(accounts_url, headers=auth_headers)
             response.raise_for_status()
             accounts = await response.json()
 
@@ -140,11 +156,8 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
             all_holdings = []
             for account in accounts:
                 account_id = account["id"]
-                positions_url = (
-                    f"{self.base_url}/accounts/{account_id}/positions"
-                )
-                pos_params = {"userId": user_id, "userSecret": user_secret}
-                pos_response = await self.client.get(positions_url, params=pos_params)
+                positions_url = f"{self.base_url}/accounts/{account_id}/positions"
+                pos_response = await self.client.get(positions_url, headers=auth_headers)
                 pos_response.raise_for_status()
                 positions = await pos_response.json()
 
@@ -165,8 +178,8 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
         access_token: str,
         start_date: date,
         end_date: date,
-        account_ids: Optional[List[str]] = None,
-    ) -> List[InvestmentTransaction]:
+        account_ids: Optional[list[str]] = None,
+    ) -> list[InvestmentTransaction]:
         """Fetch investment transactions from SnapTrade.
 
         Args:
@@ -192,12 +205,12 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
             raise ValueError("start_date must be before end_date")
 
         user_id, user_secret = self._parse_access_token(access_token)
+        auth_headers = self._auth_headers(user_id, user_secret)
 
         try:
             # Get all accounts
             accounts_url = f"{self.base_url}/accounts"
-            params = {"userId": user_id, "userSecret": user_secret}
-            response = await self.client.get(accounts_url, params=params)
+            response = await self.client.get(accounts_url, headers=auth_headers)
             response.raise_for_status()
             accounts = await response.json()
 
@@ -209,16 +222,15 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
             all_transactions = []
             for account in accounts:
                 account_id = account["id"]
-                transactions_url = (
-                    f"{self.base_url}/accounts/{account_id}/transactions"
-                )
+                transactions_url = f"{self.base_url}/accounts/{account_id}/transactions"
+                # Date params are non-sensitive, only auth goes in headers
                 tx_params = {
-                    "userId": user_id,
-                    "userSecret": user_secret,
                     "startDate": start_date.isoformat(),
                     "endDate": end_date.isoformat(),
                 }
-                tx_response = await self.client.get(transactions_url, params=tx_params)
+                tx_response = await self.client.get(
+                    transactions_url, params=tx_params, headers=auth_headers
+                )
                 tx_response.raise_for_status()
                 transactions = await tx_response.json()
 
@@ -234,9 +246,7 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
         except Exception as e:
             raise ValueError(f"SnapTrade API error: {str(e)}")
 
-    async def get_securities(
-        self, access_token: str, security_ids: List[str]
-    ) -> List[Security]:
+    async def get_securities(self, access_token: str, security_ids: list[str]) -> list[Security]:
         """Fetch security details from SnapTrade positions.
 
         Note: SnapTrade doesn't have a dedicated securities endpoint.
@@ -274,9 +284,7 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
         except Exception as e:
             raise ValueError(f"SnapTrade API error: {str(e)}")
 
-    async def get_investment_accounts(
-        self, access_token: str
-    ) -> List[InvestmentAccount]:
+    async def get_investment_accounts(self, access_token: str) -> list[InvestmentAccount]:
         """Fetch investment accounts with aggregated holdings.
 
         Returns accounts with total value, cost basis, and unrealized P&L.
@@ -297,12 +305,12 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
             ...     print(f"  P&L: {account.total_unrealized_gain_loss_percent:.2f}%")
         """
         user_id, user_secret = self._parse_access_token(access_token)
+        auth_headers = self._auth_headers(user_id, user_secret)
 
         try:
             # Get all accounts
             accounts_url = f"{self.base_url}/accounts"
-            params = {"userId": user_id, "userSecret": user_secret}
-            response = await self.client.get(accounts_url, params=params)
+            response = await self.client.get(accounts_url, headers=auth_headers)
             response.raise_for_status()
             accounts = await response.json()
 
@@ -312,11 +320,8 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
                 account_id = account["id"]
 
                 # Get positions for this account
-                positions_url = (
-                    f"{self.base_url}/accounts/{account_id}/positions"
-                )
-                pos_params = {"userId": user_id, "userSecret": user_secret}
-                pos_response = await self.client.get(positions_url, params=pos_params)
+                positions_url = f"{self.base_url}/accounts/{account_id}/positions"
+                pos_response = await self.client.get(positions_url, headers=auth_headers)
                 pos_response.raise_for_status()
                 positions = await pos_response.json()
 
@@ -328,8 +333,7 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
 
                 # Get account balances
                 balances_url = f"{self.base_url}/accounts/{account_id}/balances"
-                bal_params = {"userId": user_id, "userSecret": user_secret}
-                bal_response = await self.client.get(balances_url, params=bal_params)
+                bal_response = await self.client.get(balances_url, headers=auth_headers)
                 bal_response.raise_for_status()
                 balances = await bal_response.json()
 
@@ -340,8 +344,8 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
                     type=account.get("type", "investment"),
                     subtype=account.get("account_type"),
                     balances={
-                        "current": float(balances.get("total", {}).get("amount", 0)),
-                        "available": float(balances.get("cash", {}).get("amount", 0)),
+                        "current": Decimal(str(balances.get("total", {}).get("amount", 0))),
+                        "available": Decimal(str(balances.get("cash", {}).get("amount", 0))),
                     },
                     holdings=holdings,
                 )
@@ -354,9 +358,7 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
         except Exception as e:
             raise ValueError(f"SnapTrade API error: {str(e)}")
 
-    async def list_connections(
-        self, access_token: str
-    ) -> List[Dict[str, Any]]:
+    async def list_connections(self, access_token: str) -> list[dict[str, Any]]:
         """List brokerage connections for a user.
 
         Returns which brokerages the user has connected (E*TRADE, Robinhood, etc.).
@@ -373,20 +375,20 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
             ...     print(f"Connected: {conn['brokerage_name']}")
         """
         user_id, user_secret = self._parse_access_token(access_token)
+        auth_headers = self._auth_headers(user_id, user_secret)
 
         try:
             url = f"{self.base_url}/connections"
-            params = {"userId": user_id, "userSecret": user_secret}
-            response = await self.client.get(url, params=params)
+            response = await self.client.get(url, headers=auth_headers)
             response.raise_for_status()
-            return await response.json()
+            return cast(list[dict[str, Any]], await response.json())
 
         except httpx.HTTPStatusError as e:
             raise self._transform_error(e)
         except Exception as e:
             raise ValueError(f"SnapTrade API error: {str(e)}")
 
-    def get_brokerage_capabilities(self, brokerage_name: str) -> Dict[str, Any]:
+    def get_brokerage_capabilities(self, brokerage_name: str) -> dict[str, Any]:
         """Get capabilities for a specific brokerage.
 
         Important: Robinhood is READ-ONLY (no trading support).
@@ -476,16 +478,12 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
             user_id, user_secret = access_token.split(":", 1)
             return user_id, user_secret
         except ValueError:
-            raise ValueError(
-                "Invalid access_token format. Expected 'user_id:user_secret'"
-            )
+            raise ValueError("Invalid access_token format. Expected 'user_id:user_secret'")
 
-    def _transform_holding(
-        self, snaptrade_position: Dict[str, Any], account_id: str
-    ) -> Holding:
+    def _transform_holding(self, snaptrade_position: dict[str, Any], account_id: str) -> Holding:
         """Transform SnapTrade position data to Holding model."""
         symbol_data = snaptrade_position.get("symbol", {})
-        
+
         # Create Security from symbol data
         security = Security(
             security_id=symbol_data.get("id", symbol_data.get("symbol", "")),
@@ -499,9 +497,7 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
         # SnapTrade uses "average_purchase_price" for cost basis
         avg_price = snaptrade_position.get("average_purchase_price")
         quantity = Decimal(str(snaptrade_position.get("units", 0)))
-        cost_basis = (
-            Decimal(str(avg_price)) * quantity if avg_price is not None else None
-        )
+        cost_basis = Decimal(str(avg_price)) * quantity if avg_price is not None else None
 
         return Holding(
             account_id=account_id,
@@ -514,11 +510,11 @@ class SnapTradeInvestmentProvider(InvestmentProvider):
         )
 
     def _transform_transaction(
-        self, snaptrade_tx: Dict[str, Any], account_id: str
+        self, snaptrade_tx: dict[str, Any], account_id: str
     ) -> InvestmentTransaction:
         """Transform SnapTrade transaction to InvestmentTransaction model."""
         symbol_data = snaptrade_tx.get("symbol", {})
-        
+
         # Create Security from symbol data
         security = Security(
             security_id=symbol_data.get("id", symbol_data.get("symbol", "")),
