@@ -30,6 +30,7 @@ print(f"Net Worth: ${snapshot.total_net_worth:,.2f}")
 """
 
 import asyncio
+import logging
 import uuid
 from datetime import datetime
 from typing import Any
@@ -47,6 +48,8 @@ from fin_infra.net_worth.models import (
     NetWorthSnapshot,
 )
 
+logger = logging.getLogger(__name__)
+
 
 class NetWorthAggregator:
     """
@@ -213,16 +216,16 @@ class NetWorthAggregator:
         results = await asyncio.gather(*tasks, return_exceptions=True)
 
         # Aggregate results (skip failed providers)
-        all_assets = []
-        all_liabilities = []
-        actual_providers = []
+        all_assets: list[AssetDetail] = []
+        all_liabilities: list[LiabilityDetail] = []
+        actual_providers: list[str] = []
 
         for i, result in enumerate(results):
-            if isinstance(result, Exception):
-                # Log error but continue (graceful degradation)
-                print(f"Provider {providers_used[i]} failed: {result}")
+            if isinstance(result, BaseException):
+                logger.warning("Provider %s failed: %s", providers_used[i], result)
                 continue
 
+            # result is now tuple[list[AssetDetail], list[LiabilityDetail]]
             assets, liabilities = result
             all_assets.extend(assets)
             all_liabilities.extend(liabilities)
