@@ -121,6 +121,15 @@ class NetWorthTracker:
         self.goal_tracker = goal_tracker
         self.conversation = conversation
 
+        # Configuration set by easy_net_worth(); declared here for type checkers.
+        self.snapshot_schedule: str = "daily"
+        self.change_threshold_percent: float = 5.0
+        self.change_threshold_amount: float = 10000.0
+        self.enable_llm: bool = False
+        self.llm_provider: str | None = None
+        self.llm_model: str | None = None
+        self.config: dict[str, Any] = {}
+
     async def calculate_net_worth(
         self,
         user_id: str,
@@ -368,12 +377,20 @@ def easy_net_worth(
 
     if enable_llm:
         try:
-            from ai_infra.llm import CoreLLM
+            from ai_infra.llm.llm import LLM
         except ImportError:
             raise ImportError(
-                "LLM features require ai-infra package. " "Install with: pip install ai-infra"
+                "LLM features require ai-infra package. Install with: pip install ai-infra"
             )
 
+        cache = None
+        try:
+            from svc_infra.cache import get_cache
+
+            cache = get_cache()
+        except Exception:
+            cache = None
+
         # Determine default model
         default_models = {
             "google": "gemini-2.0-flash-exp",
@@ -384,11 +401,11 @@ def easy_net_worth(
 
         if not model_name:
             raise ValueError(
-                f"Unknown llm_provider: {llm_provider}. " f"Use 'google', 'openai', or 'anthropic'"
+                f"Unknown llm_provider: {llm_provider}. Use 'google', 'openai', or 'anthropic'"
             )
 
-        # Create shared CoreLLM instance
-        llm = CoreLLM()
+        # Create shared LLM instance
+        llm = LLM()
 
         # Create LLM components (deferred import to avoid circular dependency)
         # These modules will be created in Section 17 V2 implementation
@@ -416,18 +433,22 @@ def easy_net_worth(
             # goals.management not yet implemented, skip
             pass
 
-        try:
-            from fin_infra.conversation import FinancialPlanningConversation
+        if cache is not None:
+            try:
+                from fin_infra.conversation import FinancialPlanningConversation
 
-            conversation = FinancialPlanningConversation(
-                llm=llm,
-                cache=cache,  # Required for context storage
-                provider=llm_provider,
-                model_name=model_name,
-            )
-        except ImportError:
-            # conversation module not yet implemented, skip
-            pass
+                conversation = FinancialPlanningConversation(
+                    llm=llm,
+                    cache=cache,  # Required for context storage
+                    provider=llm_provider,
+                    model_name=model_name,
+                )
+            except ImportError:
+                # conversation module not yet implemented, skip
+                pass
+            except Exception:
+                # Cache not configured or other runtime issue; skip optional conversation wiring.
+                pass
 
     # Create tracker
     tracker = NetWorthTracker(
