@@ -1,5 +1,10 @@
 """Data normalization module for financial symbols and currencies."""
 
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from fastapi import FastAPI
+
 from fin_infra.normalization.currency_converter import (
     CurrencyConverter,
     CurrencyNotSupportedError,
@@ -64,7 +69,7 @@ def easy_normalization(
 
 
 def add_normalization(
-    app: "FastAPI",  # type: ignore
+    app: "FastAPI",
     *,
     prefix: str = "/normalize",
     api_key: str | None = None,
@@ -110,11 +115,6 @@ def add_normalization(
         - Integrated with svc-infra observability (request metrics)
         - Scoped docs at {prefix}/docs for standalone documentation
     """
-    from typing import TYPE_CHECKING
-
-    if TYPE_CHECKING:
-        from fastapi import FastAPI
-
     # Import FastAPI dependencies
     from fastapi import Query, HTTPException
 
@@ -145,19 +145,21 @@ def add_normalization(
     @router.get("/convert")
     async def convert_currency(
         amount: float = Query(..., description="Amount to convert"),
-        from_currency: str = Query(..., alias="from", description="Source currency code (e.g., USD)"),
+        from_currency: str = Query(
+            ..., alias="from", description="Source currency code (e.g., USD)"
+        ),
         to_currency: str = Query(..., alias="to", description="Target currency code (e.g., EUR)"),
     ):
         """Convert amount between currencies."""
         try:
-            result = await converter.convert(amount, from_currency, to_currency)
+            result = await converter.convert_with_details(amount, from_currency, to_currency)
             return {
-                "amount": amount,
-                "from_currency": from_currency,
-                "to_currency": to_currency,
-                "result": result.amount,
+                "amount": result.amount,
+                "from_currency": result.from_currency,
+                "to_currency": result.to_currency,
+                "result": result.converted,
                 "rate": result.rate,
-                "timestamp": result.timestamp.isoformat(),
+                "timestamp": result.date.isoformat() if result.date else None,
             }
         except CurrencyNotSupportedError as e:
             raise HTTPException(status_code=400, detail=str(e))
