@@ -24,7 +24,7 @@ from __future__ import annotations
 
 import ssl
 import httpx
-from typing import Any
+from typing import Any, cast
 
 from ..base import BankingProvider
 
@@ -93,7 +93,13 @@ class TellerClient(BankingProvider):
             ssl_context.load_cert_chain(certfile=cert_path, keyfile=key_path)
             client_kwargs["verify"] = ssl_context
 
-        self.client = httpx.Client(**client_kwargs)
+        # Create client with explicit parameters to satisfy type checker
+        self.client = httpx.Client(
+            base_url=str(client_kwargs["base_url"]),
+            timeout=float(client_kwargs["timeout"]),  # type: ignore[arg-type]
+            headers=client_kwargs["headers"],  # type: ignore[arg-type]
+            verify=client_kwargs.get("verify", True),  # type: ignore[arg-type]
+        )
 
     def _request(self, method: str, path: str, **kwargs: Any) -> Any:
         """Make HTTP request to Teller API with error handling.
@@ -139,7 +145,7 @@ class TellerClient(BankingProvider):
                 "products": ["accounts", "transactions", "balances", "identity"],
             },
         )
-        return response.get("enrollment_id", "")
+        return cast(str, response.get("enrollment_id", ""))
 
     def exchange_public_token(self, public_token: str) -> dict:
         """Exchange public token for access token.
@@ -186,7 +192,7 @@ class TellerClient(BankingProvider):
             auth=(access_token, ""),
         )
         response.raise_for_status()
-        return response.json()
+        return cast(list[dict[Any, Any]], response.json())
 
     def transactions(
         self,
@@ -229,7 +235,7 @@ class TellerClient(BankingProvider):
             params=params,
         )
         response.raise_for_status()
-        return response.json()
+        return cast(list[dict[Any, Any]], response.json())
 
     def balances(self, access_token: str, account_id: str | None = None) -> dict:
         """Fetch current balances.
@@ -261,7 +267,7 @@ class TellerClient(BankingProvider):
             )
 
         response.raise_for_status()
-        return response.json()
+        return cast(dict[Any, Any], response.json())
 
     def identity(self, access_token: str) -> dict:
         """Fetch identity/account holder information.
@@ -285,7 +291,7 @@ class TellerClient(BankingProvider):
             auth=(access_token, ""),
         )
         response.raise_for_status()
-        return response.json()
+        return cast(dict[Any, Any], response.json())
 
     def __del__(self) -> None:
         """Close HTTP client on cleanup."""
