@@ -7,7 +7,7 @@ mode for development and testing. Live trading requires explicit opt-in.
 from __future__ import annotations
 
 import os
-from typing import Literal
+from typing import Any, Literal, cast
 
 try:
     from alpaca_trade_api import REST
@@ -15,7 +15,7 @@ try:
     ALPACA_AVAILABLE = True
 except ImportError:
     ALPACA_AVAILABLE = False
-    REST = None  # type: ignore
+    REST = None
 
 from ..base import BrokerageProvider
 
@@ -55,8 +55,7 @@ class AlpacaBrokerage(BrokerageProvider):
     ) -> None:
         if not ALPACA_AVAILABLE:
             raise ImportError(
-                "alpaca-trade-api is not installed. "
-                "Install it with: pip install alpaca-trade-api"
+                "alpaca-trade-api is not installed. Install it with: pip install alpaca-trade-api"
             )
 
         # Get credentials from args or environment
@@ -105,6 +104,9 @@ class AlpacaBrokerage(BrokerageProvider):
     ) -> dict:
         """Submit an order to Alpaca.
 
+        IMPORTANT: client_order_id is auto-generated if not provided to ensure
+        idempotency. Network retries without idempotency can cause DOUBLE ORDERS.
+
         Args:
             symbol: Trading symbol (e.g., "AAPL")
             qty: Order quantity
@@ -113,14 +115,21 @@ class AlpacaBrokerage(BrokerageProvider):
             time_in_force: "day", "gtc", "ioc", or "fok" (default: "day")
             limit_price: Limit price (required for limit/stop_limit orders)
             stop_price: Stop price (required for stop/stop_limit orders)
-            client_order_id: Optional client order ID
+            client_order_id: Client order ID for idempotency. Auto-generated if not provided.
 
         Returns:
-            Order dict with id, status, filled_qty, etc.
+            Order dict with id, status, filled_qty, client_order_id, etc.
 
         Raises:
             Exception: If order submission fails
         """
+        # CRITICAL: Auto-generate client_order_id for idempotency if not provided.
+        # Without this, network retries can cause duplicate order execution = MONEY LOSS.
+        if client_order_id is None:
+            import uuid
+
+            client_order_id = str(uuid.uuid4())
+
         order = self.client.submit_order(
             symbol=symbol,
             qty=qty,
@@ -299,14 +308,14 @@ class AlpacaBrokerage(BrokerageProvider):
         return self._extract_raw(watchlist)
 
     @staticmethod
-    def _extract_raw(obj) -> dict:
+    def _extract_raw(obj: Any) -> dict[Any, Any]:
         """Extract raw dict from Alpaca entity object.
 
         Alpaca entities have a _raw attribute with the API response data.
         """
         if hasattr(obj, "_raw"):
-            return obj._raw
+            return cast(dict[Any, Any], obj._raw)
         elif hasattr(obj, "__dict__"):
-            return obj.__dict__
+            return cast(dict[Any, Any], obj.__dict__)
         else:
-            return obj
+            return cast(dict[Any, Any], obj)
