@@ -8,7 +8,7 @@ from __future__ import annotations
 
 import os
 import time
-from typing import Sequence
+from collections.abc import Sequence
 from decimal import Decimal
 from datetime import datetime, timezone
 
