@@ -13,6 +13,8 @@ from __future__ import annotations
 import importlib
 from typing import Any, TypeVar
 
+from fin_infra.exceptions import ProviderNotFoundError
+
 from .base import (
     BankingProvider,
     BrokerageProvider,
@@ -23,6 +25,15 @@ from .base import (
     TaxProvider,
 )
 
+# Re-export for backward compatibility
+__all__ = [
+    "ProviderNotFoundError",
+    "ProviderRegistry",
+    "PROVIDER_TYPES",
+    "PROVIDER_MODULES",
+    "DEFAULT_PROVIDERS",
+]
+
 T = TypeVar("T")
 
 # Provider domain to ABC mapping
@@ -77,12 +88,6 @@ DEFAULT_PROVIDERS = {
 }
 
 
-class ProviderNotFoundError(Exception):
-    """Raised when a provider cannot be found or loaded."""
-
-    pass
-
-
 class ProviderRegistry:
     """
     Registry for financial data providers.
