@@ -11,6 +11,7 @@ from __future__ import annotations
 
 import re
 from functools import lru_cache
+from typing import cast
 
 try:
     from rapidfuzz import fuzz, process
@@ -95,7 +96,7 @@ class FuzzyMatcher:
         """
         if not RAPIDFUZZ_AVAILABLE:
             raise ImportError(
-                "rapidfuzz is required for fuzzy matching. " "Install with: pip install rapidfuzz"
+                "rapidfuzz is required for fuzzy matching. Install with: pip install rapidfuzz"
             )
         self.similarity_threshold = similarity_threshold
 
@@ -165,7 +166,7 @@ class FuzzyMatcher:
         norm2 = normalize_merchant(name2)
 
         similarity = fuzz.token_sort_ratio(norm1, norm2)
-        return similarity >= self.similarity_threshold
+        return cast(bool, similarity >= self.similarity_threshold)
 
     def group_merchants(self, merchants: list[str]) -> dict[str, list[str]]:
         """
