@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import httpx
+from typing import Any, cast
 from tenacity import retry, stop_after_attempt, wait_exponential, retry_if_exception_type
 
 _DEFAULT_TIMEOUT = httpx.Timeout(20.0)
@@ -12,8 +13,8 @@ _DEFAULT_TIMEOUT = httpx.Timeout(20.0)
     retry=retry_if_exception_type(httpx.HTTPError),
     reraise=True,
 )
-async def aget_json(url: str, **kwargs) -> dict:
+async def aget_json(url: str, **kwargs) -> dict[Any, Any]:
     async with httpx.AsyncClient(timeout=_DEFAULT_TIMEOUT) as client:
         r = await client.get(url, **kwargs)
         r.raise_for_status()
-        return r.json()
+        return cast(dict[Any, Any], r.json())
