@@ -2,15 +2,17 @@ from __future__ import annotations
 
 import asyncio
 import random
-from typing import Awaitable, Callable, Iterable, TypeVar
+from typing import TypeVar
+from collections.abc import Awaitable, Callable, Iterable
+
+from fin_infra.exceptions import RetryError
+
+# Re-export for backward compatibility
+__all__ = ["RetryError", "retry_async"]
 
 T = TypeVar("T")
 
 
-class RetryError(Exception):
-    pass
-
-
 async def retry_async(
     func: Callable[[], Awaitable[T]],
     *,
@@ -27,7 +29,7 @@ async def retry_async(
     for i in range(attempts):
         try:
             return await func()
-        except tuple(retry_on) as exc:  # type: ignore[misc]
+        except tuple(retry_on) as exc:
             last_exc = exc
             if i == attempts - 1:
                 break
